#!/usr/bin/env python3

"""
RCSid:
	$Id: dnsutils.py,v 1.10 2023/06/10 17:04:16 sjg Exp $

	@(#) Copyright (c) 1997-2023 Simon J. Gerraty.

	This file is provided in the hope that it will
	be of use.  There is absolutely NO WARRANTY.
	Permission to copy, redistribute or otherwise
	use this file is hereby granted provided that 
	the above copyright notice and this notice are
	left intact. 
      
	Please send copies of changes and bug-fixes to:
	sjg@crufty.net
"""


import sys
import subprocess
import os
import getopt
import conf as cf

def add_DEBUG(a, conf):
    """add debug specifications"""
    if not 'DEBUG' in conf:
        conf['DEBUG'] = {}
    for s in a.split(','):
        if '=' in s:
            k,v = s.split('=')
        else:
            k=s
            v=1
            
        conf['DEBUG'][k] = v

def debug_print(key, msg, conf={}):
    """print to debug_file if key in DEBUG"""
    debugs = conf.get('DEBUG', {})
    if key in debugs or 'all' in debugs:
        print(msg, file=conf.get('debug_file', sys.stderr))

def install_new(list, conf={}):
    """install_xnew.sh will replace file with file.new if different"""
    if len(list) == 0:
        return
    r = subprocess.Popen(['sh',
                          cf.subst('${progdir}/install_xnew.sh', conf)],
                         universal_newlines=True,
                         stdin=subprocess.PIPE)
    for f in list:
        print(f, file=r.stdin)
    
def app_init(xopts='', xoptf=None, conf=None):
    """provide for consistent app semantics"""
    conf = cf.loadConfig('${progdir}/dns.cf', conf, False)
    conf = cf.loadConfig('${progdir}/${progname:R}.cf', conf, False)
    conf = cf.loadConfig('.../.dns.cf', conf, False)
    conf = cf.loadConfig('.../.${progname:R}.cf', conf, False)

    opts,args = getopt.getopt(sys.argv[1:], 'c:d:o:'+xopts)

    cp = os.getenv('DEBUG_SH')
    if cp:
        add_DEBUG(cp, conf)
    for o,a in opts:
        if o == '-c':
            conf = cf.loadConfig(a, conf)
        elif o == '-d':
            add_DEBUG(a, conf)
        elif o == '-o':
            conf = cf.stringConfig(a, conf)
        elif xoptf:
            xoptf(o, a, conf)

    return conf,args
